#[non_exhaustive]pub enum McpIconTheme {
Light,
Dark,
}Expand description
Icon themes supported by the MCP specification
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Light
Indicates the icon is designed to be used with a light background
Dark
Indicates the icon is designed to be used with a dark background