McpIcon

Struct McpIcon 

#[non_exhaustive]
pub struct McpIcon { pub src: String, pub mime_type: Option<String>, pub sizes: Option<Vec<String>>, pub theme: Option<IconTheme>, }
A URL pointing to an icon resource or a base64-encoded data URI.

Clients that support rendering icons MUST support at least the following MIME types:

  • image/png - PNG images (safe, universal compatibility)
  • image/jpeg (and image/jpg) - JPEG images (safe, universal compatibility)

Clients that support rendering icons SHOULD also support:

  • image/svg+xml - SVG images (scalable but requires security precautions)
  • image/webp - WebP images (modern, efficient format)

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
src: String

A standard URI pointing to an icon resource

mime_type: Option<String>

Optional override if the server’s MIME type is missing or generic

sizes: Option<Vec<String>>

Size specification, each string should be in WxH format (e.g., \"48x48\", \"96x96\") or \"any\" for scalable formats like SVG

theme: Option<IconTheme>

Optional specifier for the theme this icon is designed for If not provided, the client should assume the icon can be used with any theme.

Implementations

Source

impl Icon

pub fn new(src: impl Into<String>) -> Icon

Create a new Icon with the given source URL.

pub fn with_mime_type(self, mime_type: impl Into<String>) -> Icon

Set the MIME type.

pub fn with_sizes(self, sizes: Vec<String>) -> Icon

Set the sizes.

pub fn with_theme(self, theme: IconTheme) -> Icon

Set the theme.