McpServer

Struct McpServer 

pub struct McpServer { /* private fields */ }
In-process MCP server that owns registered tools, resources, and prompts.

Implementations

Source

impl McpServer

pub fn new( server_name: impl Into<Cow<'static, str>>, server_version: impl Into<Cow<'static, str>>, ) -> Self

Create a dynamic MCP tool server with the advertised metadata.

pub fn builder( server_name: impl Into<Cow<'static, str>>, server_version: impl Into<Cow<'static, str>>, ) -> McpServerBuilder

Start building a dynamic MCP tool server with generated registrars.

pub fn from_tool_registry( server_name: impl Into<Cow<'static, str>>, server_version: impl Into<Cow<'static, str>>, tools: McpToolRegistry, ) -> Self

Create a dynamic MCP server from an existing tool registry.

pub fn tool_registry(&self) -> &McpToolRegistry

Borrow the shared tool registry.

pub fn tool_registry_mut(&mut self) -> &mut McpToolRegistry

Mutably borrow the shared tool registry.

pub fn into_tool_registry(self) -> McpToolRegistry

Consume the server and return its tool registry.

pub fn add_tool<Call>( &mut self, definition: ToolDefinition, call: Call, ) -> Result<(), McpToolError>
where Call: Fn(McpToolCall) -> ToolCallResult + Send + Sync + 'static,

Register a synchronous MCP tool handler.

Errors

Returns McpToolError when definition is invalid or a tool with the same name is already registered.

pub fn add_typed_tool<Input, Call>( &mut self, definition: McpTypedTool<Input>, call: Call, ) -> Result<(), McpToolError>
where Input: McpToolInput, Call: Fn(Input) -> ToolCallResult + Send + Sync + 'static,

Register a synchronous typed MCP tool handler.

Errors

Returns McpToolError when definition is invalid or a tool with the same name is already registered.

pub fn add_koruma_tool<Input, Call>( &mut self, definition: McpTypedTool<Input>, call: Call, ) -> Result<(), McpToolError>
where Input: McpToolInput + ValidateExt, Input::Error: ValidationIssues, Call: Fn(Input) -> ToolCallResult + Send + Sync + 'static,

Register a typed handler with Koruma validation before dispatch.

Errors

Returns McpToolError for an invalid or duplicate tool definition.

pub fn add_tool_async<Call, Fut>( &mut self, definition: ToolDefinition, call: Call, ) -> Result<(), McpToolError>
where Call: Fn(McpToolCall) -> Fut + Send + Sync + 'static, Fut: Future<Output = ToolCallResult> + Send + 'static,

Register an async MCP tool handler.

Errors

Returns McpToolError when definition is invalid or a tool with the same name is already registered.

pub fn add_typed_tool_async<Input, Call, Fut>( &mut self, definition: McpTypedTool<Input>, call: Call, ) -> Result<(), McpToolError>
where Input: McpToolInput, Call: Fn(Input) -> Fut + Send + Sync + 'static, Fut: Future<Output = ToolCallResult> + Send + 'static,

Register an async typed MCP tool handler.

Errors

Returns McpToolError when definition is invalid or a tool with the same name is already registered.

pub fn add_koruma_tool_async<Input, Call, Fut>( &mut self, definition: McpTypedTool<Input>, call: Call, ) -> Result<(), McpToolError>
where Input: McpToolInput + ValidateExt, Input::Error: ValidationIssues, Call: Fn(Input) -> Fut + Send + Sync + 'static, Fut: Future<Output = ToolCallResult> + Send + 'static,

Register an async typed handler with Koruma validation before dispatch.

Errors

Returns McpToolError for an invalid or duplicate tool definition.

pub fn list_tools(&self) -> Vec<ToolDefinition>

Return registered MCP tool definitions.

pub fn contains_tool(&self, name: &str) -> bool

Whether a tool name is already registered.

pub fn tool_count(&self) -> usize

Number of registered tools.

pub fn add_resource<Read>( &mut self, definition: ResourceDefinition, read: Read, ) -> Result<(), McpToolError>
where Read: Fn() -> ReadResourceResult + Send + Sync + 'static,

Register a static MCP resource reader.

Errors

Returns McpToolError when definition is invalid or a resource with the same URI is already registered.

pub fn add_resource_async<Read, Fut>( &mut self, definition: ResourceDefinition, read: Read, ) -> Result<(), McpToolError>
where Read: Fn() -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<ReadResourceResult, ErrorData>> + Send + 'static,

Register an async MCP resource reader.

Errors

Returns McpToolError when definition is invalid or a resource with the same URI is already registered.

pub fn add_resource_template( &mut self, definition: ResourceTemplateDefinition, ) -> Result<(), McpToolError>

Register an MCP resource template advertised by resources/templates/list.

Errors

Returns McpToolError when definition is invalid.

pub fn list_resources(&self) -> Vec<ResourceDefinition>

Return registered MCP resource definitions.

pub fn list_resource_templates(&self) -> Vec<ResourceTemplateDefinition>

Return registered MCP resource template definitions.

pub fn contains_resource(&self, uri: &str) -> bool

Whether a resource URI is already registered.

pub fn resource_count(&self) -> usize

Number of registered concrete resources.

pub fn add_prompt<Get>( &mut self, definition: PromptDefinition, get: Get, ) -> Result<(), McpToolError>
where Get: Fn(Option<JsonObject>) -> GetPromptResult + Send + Sync + 'static,

Register a static MCP prompt.

Errors

Returns McpToolError when definition is invalid or a prompt with the same name is already registered.

pub fn add_prompt_async<Get, Fut>( &mut self, definition: PromptDefinition, get: Get, ) -> Result<(), McpToolError>
where Get: Fn(Option<JsonObject>) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<GetPromptResult, ErrorData>> + Send + 'static,

Register an async MCP prompt.

Errors

Returns McpToolError when definition is invalid or a prompt with the same name is already registered.

pub fn list_prompts(&self) -> Vec<PromptDefinition>

Return registered MCP prompt definitions.

pub fn contains_prompt(&self, name: &str) -> bool

Whether a prompt name is already registered.

pub fn prompt_count(&self) -> usize

Number of registered prompts.

pub fn call_tool(&self, name: &str, arguments: Option<Value>) -> ToolCallResult

Calls a registered tool and converts validation or handler failures into a protocol-level tool result.

pub async fn call_tool_async( &self, name: &str, arguments: Option<Value>, ) -> ToolCallResult

Asynchronously calls a registered tool and converts validation or handler failures into a protocol-level tool result.

pub async fn serve_stdio(self) -> ServeStdioResult

Serve this server over stdin/stdout using the MCP stdio transport.

Errors

Returns an error when stdio serving fails or the service task fails.

pub fn serve_stdio_blocking(self) -> ServeStdioResult

Serve this server over stdin/stdout on a new Tokio runtime.

Errors

Returns an error when the Tokio runtime cannot be created, stdio serving fails, or the service task fails.