McpServerBuilder

Struct McpServerBuilder 

pub struct McpServerBuilder { /* private fields */ }
Builder for composing generated MCP server registrars.

Implementations

Source

impl McpServerBuilder

pub fn new( server_name: impl Into<Cow<'static, str>>, server_version: impl Into<Cow<'static, str>>, ) -> Self

Create a builder with advertised server metadata.

pub fn register<Register>(self, register: Register) -> Self
where Register: FnOnce(&mut McpServer) -> Result<(), McpToolError>,

Runs a registrar against the server being built.

pub fn tool<Call>(self, definition: ToolDefinition, call: Call) -> Self
where Call: Fn(McpToolCall) -> ToolCallResult + Send + Sync + 'static,

Add a synchronous MCP tool to the server being built.

pub fn typed_tool<Input, Call>( self, definition: McpTypedTool<Input>, call: Call, ) -> Self
where Input: McpToolInput, Call: Fn(Input) -> ToolCallResult + Send + Sync + 'static,

Add a synchronous typed MCP tool to the server being built.

pub fn tool_async<Call, Fut>( self, definition: ToolDefinition, call: Call, ) -> Self
where Call: Fn(McpToolCall) -> Fut + Send + Sync + 'static, Fut: Future<Output = ToolCallResult> + Send + 'static,

Add an async MCP tool to the server being built.

pub fn typed_tool_async<Input, Call, Fut>( self, definition: McpTypedTool<Input>, call: Call, ) -> Self
where Input: McpToolInput, Call: Fn(Input) -> Fut + Send + Sync + 'static, Fut: Future<Output = ToolCallResult> + Send + 'static,

Add an async typed MCP tool to the server being built.

pub fn resource<Read>(self, definition: ResourceDefinition, read: Read) -> Self
where Read: Fn() -> ReadResourceResult + Send + Sync + 'static,

Add a static MCP resource to the server being built.

pub fn resource_async<Read, Fut>( self, definition: ResourceDefinition, read: Read, ) -> Self
where Read: Fn() -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<ReadResourceResult, ErrorData>> + Send + 'static,

Add an async MCP resource to the server being built.

pub fn resource_template(self, definition: ResourceTemplateDefinition) -> Self

Add an MCP resource template to the server being built.

pub fn prompt<Get>(self, definition: PromptDefinition, get: Get) -> Self
where Get: Fn(Option<JsonObject>) -> GetPromptResult + Send + Sync + 'static,

Add a static MCP prompt to the server being built.

pub fn prompt_async<Get, Fut>( self, definition: PromptDefinition, get: Get, ) -> Self
where Get: Fn(Option<JsonObject>) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<GetPromptResult, ErrorData>> + Send + 'static,

Add an async MCP prompt to the server being built.

pub fn build(self) -> Result<McpServer, McpToolError>

Finish the builder and return the composed server.

Errors

Returns the first McpToolError produced by a builder registrar.

pub async fn serve_stdio(self) -> ServeStdioResult

Build and serve this server over stdin/stdout using the MCP stdio transport.

Errors

Returns an error when a builder registrar fails, stdio serving fails, or the service task fails.

pub fn serve_stdio_blocking(self) -> ServeStdioResult

Build and serve this server over stdin/stdout on a new Tokio runtime.

Errors

Returns an error when a builder registrar fails, the Tokio runtime cannot be created, stdio serving fails, or the service task fails.